import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom
} from 'd3';

import { dropdownMenu } from './dropdownMenu';
import { loadAndProcessData } from './loadAndProcessData';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width'); 
const height = +svg.attr('height');


let data;
let xColumn;
let yColumn;


const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};




const render = () => { 
  select('#x-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });
  
  select('#y-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    circleRadius: 5,
    yAxisLabel: yColumn,
    margin: { top: 10, right: 40, bottom: 88, left: 150 },
    width,
    height,
    data
  }); 
};
  

csv('https://vizhub.com/jons288/datasets/avocado_2017.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d.Date = +d.Date;
      d.AveragePrice = +d.AveragePrice;
      d.TotalVolume = +d.TotalVolume;
      d.PLU_4046 = +d.PLU_4046;
      d.PLU_4225 = +d.PLU_4225;
      d.PLU_4770 = +d.PLU_4770;
      d.TotalBags = +d.TotalBags;
      d.SmallBags = +d.SmallBags;
      d.LargeBags = +d.LargeBags;
      d.XLargeBags = +d.XLargeBags;
      d.type = +d.type;
      d.year = +d.year; 
      d.region = +d.region; 
    });
    xColumn = data.columns[4];
    yColumn = data.columns[2];
    render();
  });